# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/CalibrationMatricesCollection.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.vision import CalibrationMatrices_pb2 as rst_dot_vision_dot_CalibrationMatrices__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/CalibrationMatricesCollection.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n.rst/vision/CalibrationMatricesCollection.proto\x12\nrst.vision\x1a$rst/vision/CalibrationMatrices.proto\"Q\n\x1d\x43\x61librationMatricesCollection\x12\x30\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x1f.rst.vision.CalibrationMatricesB#B!CalibrationMatricesCollectionType')
  ,
  dependencies=[rst_dot_vision_dot_CalibrationMatrices__pb2.DESCRIPTOR,])




_CALIBRATIONMATRICESCOLLECTION = _descriptor.Descriptor(
  name='CalibrationMatricesCollection',
  full_name='rst.vision.CalibrationMatricesCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.vision.CalibrationMatricesCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=181,
)

_CALIBRATIONMATRICESCOLLECTION.fields_by_name['element'].message_type = rst_dot_vision_dot_CalibrationMatrices__pb2._CALIBRATIONMATRICES
DESCRIPTOR.message_types_by_name['CalibrationMatricesCollection'] = _CALIBRATIONMATRICESCOLLECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CalibrationMatricesCollection = _reflection.GeneratedProtocolMessageType('CalibrationMatricesCollection', (_message.Message,), dict(
  DESCRIPTOR = _CALIBRATIONMATRICESCOLLECTION,
  __module__ = 'rst.vision.CalibrationMatricesCollection_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.CalibrationMatricesCollection)
  ))
_sym_db.RegisterMessage(CalibrationMatricesCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B!CalibrationMatricesCollectionType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/nao/Modules.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/nao/Modules.proto',
  package='rst.devices.nao',
  syntax='proto2',
  serialized_pb=_b('\n\x1drst/devices/nao/Modules.proto\x12\x0frst.devices.nao\"j\n\x07Modules\x12(\n\x07modules\x18\x01 \x03(\x0b\x32\x17.rst.devices.nao.Module\x12\x35\n\x14\x66ramemanager_modules\x18\x02 \x03(\x0b\x32\x17.rst.devices.nao.Module\"\x16\n\x06Module\x12\x0c\n\x04name\x18\x01 \x02(\tB\rB\x0bModulesType')
)




_MODULES = _descriptor.Descriptor(
  name='Modules',
  full_name='rst.devices.nao.Modules',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='modules', full_name='rst.devices.nao.Modules.modules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='framemanager_modules', full_name='rst.devices.nao.Modules.framemanager_modules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50,
  serialized_end=156,
)


_MODULE = _descriptor.Descriptor(
  name='Module',
  full_name='rst.devices.nao.Module',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.devices.nao.Module.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=158,
  serialized_end=180,
)

_MODULES.fields_by_name['modules'].message_type = _MODULE
_MODULES.fields_by_name['framemanager_modules'].message_type = _MODULE
DESCRIPTOR.message_types_by_name['Modules'] = _MODULES
DESCRIPTOR.message_types_by_name['Module'] = _MODULE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Modules = _reflection.GeneratedProtocolMessageType('Modules', (_message.Message,), dict(
  DESCRIPTOR = _MODULES,
  __module__ = 'rst.devices.nao.Modules_pb2'
  # @@protoc_insertion_point(class_scope:rst.devices.nao.Modules)
  ))
_sym_db.RegisterMessage(Modules)

Module = _reflection.GeneratedProtocolMessageType('Module', (_message.Message,), dict(
  DESCRIPTOR = _MODULE,
  __module__ = 'rst.devices.nao.Modules_pb2'
  # @@protoc_insertion_point(class_scope:rst.devices.nao.Module)
  ))
_sym_db.RegisterMessage(Module)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\013ModulesType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/hri/GroupHypothesisCollection.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.hri import GroupHypothesis_pb2 as rst_dot_hri_dot_GroupHypothesis__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/hri/GroupHypothesisCollection.proto',
  package='rst.hri',
  syntax='proto2',
  serialized_pb=_b('\n\'rst/hri/GroupHypothesisCollection.proto\x12\x07rst.hri\x1a\x1drst/hri/GroupHypothesis.proto\"F\n\x19GroupHypothesisCollection\x12)\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x18.rst.hri.GroupHypothesisB\x1f\x42\x1dGroupHypothesisCollectionType')
  ,
  dependencies=[rst_dot_hri_dot_GroupHypothesis__pb2.DESCRIPTOR,])




_GROUPHYPOTHESISCOLLECTION = _descriptor.Descriptor(
  name='GroupHypothesisCollection',
  full_name='rst.hri.GroupHypothesisCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.hri.GroupHypothesisCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=153,
)

_GROUPHYPOTHESISCOLLECTION.fields_by_name['element'].message_type = rst_dot_hri_dot_GroupHypothesis__pb2._GROUPHYPOTHESIS
DESCRIPTOR.message_types_by_name['GroupHypothesisCollection'] = _GROUPHYPOTHESISCOLLECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GroupHypothesisCollection = _reflection.GeneratedProtocolMessageType('GroupHypothesisCollection', (_message.Message,), dict(
  DESCRIPTOR = _GROUPHYPOTHESISCOLLECTION,
  __module__ = 'rst.hri.GroupHypothesisCollection_pb2'
  # @@protoc_insertion_point(class_scope:rst.hri.GroupHypothesisCollection)
  ))
_sym_db.RegisterMessage(GroupHypothesisCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\035GroupHypothesisCollectionType'))
# @@protoc_insertion_point(module_scope)
